camelot.camelot.view.controls.delegates

Package camelot :: Package camelot :: Package view :: Package controls :: Module delegates |
[hide private]
[frames] | no frames]

# Module delegates

source code

Contains classes for using custom delegates

Classes | [hide private]
| GenericDelegate Manages custom delegates
| IntegerColumnDelegate Custom delegate for integer values
| PlainTextColumnDelegate Custom delegate for simple string values
| TimeColumnDelegate
| DateTimeColumnDelegate
| DateColumnDelegate Custom delegate for date values
| CodeColumnDelegate
| VirtualAddressColumnDelegate
| FloatColumnDelegate Custom delegate for float values
| Many2OneColumnDelegate Custom delegate for many 2 one relations
| One2ManyColumnDelegate Custom delegate for many 2 one relations
| BoolColumnDelegate Custom delegate for boolean values
| ImageColumnDelegate
| RichTextColumnDelegate
| ComboBoxColumnDelegate

Functions | [hide private]
_paint_not_editable(painter, option, index) | source code
create_constant_function(constant) | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.controls.delegates')`
| _registered_delegates_ = `{}`
| verbose = `False`